import { Component, OnInit } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { MatDialog } from '@angular/material/dialog';
import { CommandDetailComponent } from './detail-command/command-detail.component';
import { CreateCommandComponent } from './create-command/create-command.component';
import { DeleteModalComponent } from '../../../shared/delete_modal/delete-modal/delete-modal.component';
import { ToastrService } from 'ngx-toastr';

@Component({
  selector: 'app-commands',
  templateUrl: './commands.component.html',
  styleUrls: ['./commands.component.css']
})
export class CommandsComponent implements OnInit {
  baseUrl: string = import.meta.env.NG_APP_BASE_API_URL;
  commands: any[] = [];
  displayedColumns: string[] = ['name', 'createdBy', 'createdAt', 'actions']; 
  private apiUrl = 'http://127.0.0.1:8001/commands?page=1&itemsPerPage=30';

  constructor(private http: HttpClient, private dialog: MatDialog, private toastService: ToastrService) { }

  ngOnInit(): void {
    this.loadCommands();
  }

  loadCommands(): void {
    this.http.get<any>(this.apiUrl).subscribe(
      (data) => {
        this.commands = data['hydra:member'];
      },
      (error) => {
        console.error('Error fetching commands', error);
      }
    );
  }

  openCreateCommandModal(): void {
    const dialogRef = this.dialog.open(CreateCommandComponent, {
      width: '600px'
    });

    dialogRef.afterClosed().subscribe(result => {
      this.loadCommands();
    });
  }

  editCommand(command: any): void {
    const dialogRef = this.dialog.open(CreateCommandComponent, {
      width: '600px',
      data: { command: command } 
    });

    dialogRef.afterClosed().subscribe(result => {
      if (result) {
        console.log('Comando editado:', result);
        this.loadCommands(); 
      }
    });
  }

  viewDetails(command: any): void {
    const dialogRef = this.dialog.open(CommandDetailComponent, {
      width: '800px',
      data: command 
    });

    dialogRef.afterClosed().subscribe(result => {
      this.loadCommands(); 
    });
  }

  deleteCommand(command: any): void { 
    const dialogRef = this.dialog.open(DeleteModalComponent, 
      {
        width: '300px', 
        data: { name: command.name } 
      });
  
      dialogRef.afterClosed().subscribe(result => {
        if (result) {
          const apiUrl = `${this.baseUrl}/commands/${command.uuid}`;
    
          this.http.delete(apiUrl).subscribe({
            next: () => {
              console.log('Role deleted successfully');
              this.loadCommands();
              this.toastService.success('Role deleted successfully'); 
            },
            error: (error) => {
              console.error('Error deleting role:', error);
            }
          });
        } else {
          console.log('Role deletion cancelled');
        }
      });
  }

}
